@@ -17,7 +17,7 @@ import Typography from "@material-ui/core/Typography";
 import React, { useCallback, useState } from "react";
 import { useDispatch } from "react-redux";
 import { useHistory } from "react-router";
-import { toggleSnackbar } from "../../../../actions";
+import { toggleSnackbar } from "../../../../redux/explorer";
 import API from "../../../../middleware/Api";
 import { getNumber } from "../../../../utils";
 import DomainInput from "../../Common/DomainInput";
@@ -94,7 +94,7 @@ const steps = [
         optional: false,
     },
     {
-        title: "上传限制",
+        title: "上传设置",
         optional: false,
     },
     {
@@ -138,6 +138,7 @@ export default function COSGuide(props) {
                   MaxSize: "0",
                   OptionsSerialized: {
                       file_type: "",
+                      placeholder_with_size: "false",
                   },
               }
     );
@@ -191,6 +192,11 @@ export default function COSGuide(props) {
             policyCopy.IsOriginLinkEnable === "true";
         policyCopy.IsPrivate = policyCopy.IsPrivate === "true";
         policyCopy.MaxSize = parseInt(policyCopy.MaxSize);
+        policyCopy.OptionsSerialized.chunk_size = parseInt(
+            policyCopy.OptionsSerialized.chunk_size
+        );
+        policyCopy.OptionsSerialized.placeholder_with_size =
+            policyCopy.OptionsSerialized.placeholder_with_size === "true";
         policyCopy.OptionsSerialized.file_type = policyCopy.OptionsSerialized.file_type.split(
             ","
         );
@@ -965,6 +971,53 @@ export default function COSGuide(props) {
                         </div>
                     </Collapse>
 
+                    <div className={classes.subStepContainer}>
+                        <div className={classes.stepNumberContainer}>
+                            <div className={classes.stepNumber}>
+                                {getNumber(3, [
+                                    policy.MaxSize !== "0",
+                                    policy.OptionsSerialized.file_type !== "",
+                                ])}
+                            </div>
+                        </div>
+                        <div className={classes.subStepContent}>
+                            <Typography variant={"body2"}>
+                                是否要再用户开始上传时就创建占位符文件并扣除用户容量？开启后，可以防止用户恶意发起多个上传请求但不完成上传。
+                            </Typography>
+                            <div className={classes.form}>
+                                <FormControl required component="fieldset">
+                                    <RadioGroup
+                                        aria-label="gender"
+                                        name="gender1"
+                                        value={
+                                            policy.OptionsSerialized
+                                                .placeholder_with_size
+                                        }
+                                        onChange={handleOptionChange(
+                                            "placeholder_with_size"
+                                        )}
+                                        row
+                                    >
+                                        <FormControlLabel
+                                            value={"true"}
+                                            control={
+                                                <Radio color={"primary"} />
+                                            }
+                                            label="创建占位符文件"
+                                        />
+                                        <FormControlLabel
+                                            value={"false"}
+                                            control={
+                                                <Radio color={"primary"} />
+                                            }
+                                            label="不创建"
+                                        />
+                                    </RadioGroup>
+                                </FormControl>
+                            </div>
+                        </div>
+                    </div>
+
                     <div className={classes.stepFooter}>
                         <Button
                             color={"default"}
