@@ -15,12 +15,13 @@ import Typography from "@material-ui/core/Typography";
 import React, { useCallback, useEffect, useState } from "react";
 import { useDispatch } from "react-redux";
 import { useHistory } from "react-router";
-import { toggleSnackbar } from "../../../../actions";
+import { toggleSnackbar } from "../../../../redux/explorer";
 import API from "../../../../middleware/Api";
 import SizeInput from "../../Common/SizeInput";
 import AlertDialog from "../../Dialogs/Alert";
 import MagicVar from "../../Dialogs/MagicVar";
 import DomainInput from "../../Common/DomainInput";
+import { getNumber } from "../../../../utils";
 
 const useStyles = makeStyles((theme) => ({
     stepContent: {
@@ -92,7 +93,7 @@ const steps = [
         optional: false,
     },
     {
-        title: "上传限制",
+        title: "上传设置",
         optional: false,
     },
     {
@@ -145,6 +146,8 @@ export default function OneDriveGuide(props) {
                       od_redirect: "",
                       od_proxy: "",
                       od_driver: "",
+                      chunk_size: 50 << 20,
+                      placeholder_with_size: "false",
                   },
               }
     );
@@ -248,6 +251,11 @@ export default function OneDriveGuide(props) {
             policyCopy.IsOriginLinkEnable === "true";
         policyCopy.IsPrivate = policyCopy.IsPrivate === "true";
         policyCopy.MaxSize = parseInt(policyCopy.MaxSize);
+        policyCopy.OptionsSerialized.chunk_size = parseInt(
+            policyCopy.OptionsSerialized.chunk_size
+        );
+        policyCopy.OptionsSerialized.placeholder_with_size =
+            policyCopy.OptionsSerialized.placeholder_with_size === "true";
         policyCopy.OptionsSerialized.file_type = policyCopy.OptionsSerialized.file_type.split(
             ","
         );
@@ -1010,11 +1018,86 @@ export default function OneDriveGuide(props) {
                         </div>
                     </Collapse>
 
+                    <div className={classes.subStepContainer}>
+                        <div className={classes.stepNumberContainer}>
+                            <div className={classes.stepNumber}>
+                                {getNumber(3, [
+                                    policy.MaxSize !== "0",
+                                    policy.OptionsSerialized.file_type !== "",
+                                ])}
+                            </div>
+                        </div>
+                        <div className={classes.subStepContent}>
+                            <Typography variant={"body2"}>
+                                请指定分片上传时的分片大小，OneDrive 要求必须为
+                                320 KiB (327,680 bytes) 的整数倍。
+                                <br />
+                                启用分片上传后，用户上传的文件将会被切分成分片逐个上传到存储端，当上传中断后，用户可以选择从上次上传的分片后继续开始上传。
+                            </Typography>
+                            <div className={classes.form}>
+                                <SizeInput
+                                    value={policy.OptionsSerialized.chunk_size}
+                                    onChange={handleOptionChange("chunk_size")}
+                                    min={0}
+                                    max={9223372036854775807}
+                                    label={"分片上传大小"}
+                                />
+                            </div>
+                        </div>
+                    </div>
+
+                    <div className={classes.subStepContainer}>
+                        <div className={classes.stepNumberContainer}>
+                            <div className={classes.stepNumber}>
+                                {getNumber(4, [
+                                    policy.MaxSize !== "0",
+                                    policy.OptionsSerialized.file_type !== "",
+                                ])}
+                            </div>
+                        </div>
+                        <div className={classes.subStepContent}>
+                            <Typography variant={"body2"}>
+                                是否要再用户开始上传时就创建占位符文件并扣除用户容量？开启后，可以防止用户恶意发起多个上传请求但不完成上传。
+                            </Typography>
+                            <div className={classes.form}>
+                                <FormControl required component="fieldset">
+                                    <RadioGroup
+                                        aria-label="gender"
+                                        name="gender1"
+                                        value={
+                                            policy.OptionsSerialized
+                                                .placeholder_with_size
+                                        }
+                                        onChange={handleOptionChange(
+                                            "placeholder_with_size"
+                                        )}
+                                        row
+                                    >
+                                        <FormControlLabel
+                                            value={"true"}
+                                            control={
+                                                <Radio color={"primary"} />
+                                            }
+                                            label="创建占位符文件"
+                                        />
+                                        <FormControlLabel
+                                            value={"false"}
+                                            control={
+                                                <Radio color={"primary"} />
+                                            }
+                                            label="不创建"
+                                        />
+                                    </RadioGroup>
+                                </FormControl>
+                            </div>
+                        </div>
+                    </div>
+
                     <div className={classes.stepFooter}>
                         <Button
                             color={"default"}
                             className={classes.button}
-                            onClick={() => setActiveStep(2)}
+                            onClick={() => setActiveStep(4)}
                         >
                             上一步
                         </Button>{" "}
