@@ -6,27 +6,26 @@ import RightIcon from "@material-ui/icons/KeyboardArrowRight";
 import ShareIcon from "@material-ui/icons/Share";
 import NewFolderIcon from "@material-ui/icons/CreateNewFolder";
 import RefreshIcon from "@material-ui/icons/Refresh";
-import {
+import explorer, {
+    drawerToggleAction,
     navigateTo,
     navigateUp,
-    setNavigatorError,
-    setNavigatorLoadingStatus,
-    refreshFileList,
-    setSelectedTarget,
+    openCompressDialog,
+    openCreateFileDialog,
     openCreateFolderDialog,
     openShareDialog,
-    drawerToggleAction,
-    openCompressDialog,
-} from "../../../actions/index";
-import explorer from "../../../redux/explorer";
-import API from "../../../middleware/Api";
-import { setCookie, setGetParameter, fixUrlHash } from "../../../utils/index";
+    refreshFileList,
+    setNavigatorError,
+    setNavigatorLoadingStatus,
+    setSelectedTarget,
+} from "../../../redux/explorer";
+import { fixUrlHash, setGetParameter } from "../../../utils/index";
 import {
-    withStyles,
     Divider,
+    ListItemIcon,
     Menu,
     MenuItem,
-    ListItemIcon,
+    withStyles,
 } from "@material-ui/core";
 import PathButton from "./PathButton";
 import DropDown from "./DropDown";
@@ -36,8 +35,9 @@ import Auth from "../../../middleware/Auth";
 import Avatar from "@material-ui/core/Avatar";
 import { Archive } from "@material-ui/icons";
 import { FilePlus } from "mdi-material-ui";
-import { openCreateFileDialog } from "../../../actions";
 import SubActions from "./SubActions";
+import { setCurrentPolicy } from "../../../redux/explorer/action";
+import { list } from "../../../services/navigate";
 
 const mapStateToProps = (state) => {
     return {
@@ -88,6 +88,9 @@ const mapDispatchToProps = (dispatch) => {
         openCompressDialog: () => {
             dispatch(openCompressDialog());
         },
+        setCurrentPolicy: (policy) => {
+            dispatch(setCurrentPolicy(policy));
+        },
     };
 };
 
@@ -174,27 +177,24 @@ class NavigatorComponent extends Component {
                     ? path.substr(1).split("/")
                     : this.props.path.substr(1).split("/"),
         });
-        let newPath = path !== null ? path : this.props.path;
-        const apiURL = this.props.share
-            ? "/share/list/" + this.props.share.key
-            : this.keywords === ""
-            ? "/directory"
-            : "/file/search/";
-        newPath = this.keywords === "" ? newPath : this.keywords;
-
-        API.get(apiURL + encodeURIComponent(newPath))
+        const newPath = path !== null ? path : this.props.path;
+        list(newPath, this.props.share, this.keywords)
             .then((response) => {
                 this.currentID = response.data.parent;
                 this.props.updateFileList(response.data.objects);
                 this.props.setNavigatorLoadingStatus(false);
-                const pathTemp = (path !== null
-                    ? path.substr(1).split("/")
-                    : this.props.path.substr(1).split("/")
-                ).join(",");
-                setCookie("path_tmp", encodeURIComponent(pathTemp), 1);
                 if (this.keywords === "") {
                     setGetParameter("path", encodeURIComponent(newPath));
                 }
+                if (response.data.policy) {
+                    this.props.setCurrentPolicy({
+                        id: response.data.policy.id,
+                        name: response.data.policy.name,
+                        type: response.data.policy.type,
+                        maxSize: response.data.policy.max_size,
+                        allowedSuffix: response.data.policy.file_type,
+                    });
+                }
             })
             .catch((error) => {
                 this.props.setNavigatorError(true, error);
